pub(super) fn trace_addresses(
result: &TraceResult,
) -> impl Iterator<Item = Address>Expand description
Returns the distinct non-zero addresses and callers seen in the traces of result.
pub(super) fn trace_addresses(
result: &TraceResult,
) -> impl Iterator<Item = Address>Returns the distinct non-zero addresses and callers seen in the traces of result.